Kubernetes
==========

Running the complete BTB Benchmarking suite can take a long time.

For this reason, it comes prepared to be executed distributedly over a dask cluster created using Kubernetes.

.. mdinclude:: ../benchmark/KUBERNETES.md
    :start-line: 19
